@@ -1,3 +1,4 @@
+import traceback
 import requests
 import json
 import time
@@ -133,20 +134,15 @@ class InstaLog:
         return date_time.strftime("%d/%b/%Y %H:%M:%S")
 
     def exc_info_from_error(self, error):
-        if isinstance(error, tuple) and len(error) == 3:
-            exc_type, exc_value, tb = error
-        elif isinstance(error, BaseException):
-            tb = getattr(error, "__traceback__", None)
-            if tb is not None:
-                exc_type = type(error)
-                exc_value = error
-            else:
-                exc_type, exc_value, tb = sys.exc_info()
-                if exc_value is not error:
-                    tb = None
-                    exc_value = error
-                    exc_type = type(error)
+        tb = getattr(error, "__traceback__", None)
+        if tb is not None:
+            exc_type = type(error)
+            exc_value = error
         else:
-            raise ValueError("Expected Exception object to report, got %s!" % type(error))
+            exc_type, exc_value, tb = sys.exc_info()
+            if exc_value is not error:
+                tb = None
+                exc_value = error
+                exc_type = type(error)
 
-        return exc_type, exc_value, tb
+        return exc_value, ''.join(traceback.format_tb(tb))
